@@ -93,7 +93,7 @@
               msg <- paste0 ("Unable to obtain R package '",usrk,"/",pkgk,"' from '",remote_idk, "'.\n",
 							 "Check spelling of package, make sure it is an R package, and that it is available\n",
 							 "on '",remote_idk, "',  check your internet connection, and/or visit ",
-							 "http://groundhogR.com/troubleshoot.")
+							 "https://groundhogR.com/troubleshoot.")
 							 
 			gstop(msg) #utils #51
 			
